pub trait EthCallBundleApiServer:
Sized
+ Send
+ Sync
+ 'static {
// Required method
fn call_bundle<'life0, 'async_trait>(
&'life0 self,
request: EthCallBundle,
) -> Pin<Box<dyn Future<Output = RpcResult<EthCallBundleResponse>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
// Provided method
fn into_rpc(self) -> RpcModule<Self> { ... }
}Expand description
Server trait implementation for the EthCallBundleApi RPC API.
Required Methods
Sourcefn call_bundle<'life0, 'async_trait>(
&'life0 self,
request: EthCallBundle,
) -> Pin<Box<dyn Future<Output = RpcResult<EthCallBundleResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn call_bundle<'life0, 'async_trait>(
&'life0 self,
request: EthCallBundle,
) -> Pin<Box<dyn Future<Output = RpcResult<EthCallBundleResponse>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
eth_callBundle can be used to simulate a bundle against a specific block number,
including simulating a bundle at the top of the next block.
Provided Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".